package uk.co.martinpearman.b4a.mylistview.arrayadapter;

import java.util.ArrayList;
import java.util.List;

import android.widget.ListView;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Hide;

@Hide
public class MyListView extends ListView {
	/*
	 * This class extends the ListView class and uses a custom ArrayAdapter to populate the ListView.
	 */
	private MyListViewAdapter mMyListViewAdapter;

	public MyListView(BA pBA, String pEventName) {
		super(pBA.context);

		this.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.FILL_PARENT));

		/*
		 * The custom adapter is constructed with an empty data set.
		 */
		List<MyDataClass> myData = new ArrayList<MyDataClass>();

		/*
		 * Here's where you define the name of the layout file to be used for each ListItem
		 */
		int itemLayoutResourceId = BA.applicationContext.getResources().getIdentifier("my_list_view_item", "layout", BA.packageName);

		/*	as MyListViewAdapter overrides it's native class method getItem() i think aTextViewResourceId is NOT used.
		 * I think it would only be used if the ArrayAdapter's default getItem() method is used.
		 */
		int aTextViewResourceId = BA.applicationContext.getResources().getIdentifier("item_title", "id", BA.packageName);

		/*
		 * Construct the custom adapter and set it as this ListView's adapter.
		 */
		mMyListViewAdapter = new MyListViewAdapter(pBA, itemLayoutResourceId, aTextViewResourceId, myData, pEventName);
		this.setAdapter(mMyListViewAdapter);

		//	this is where we set the ListView's OnItemClickListener to the instance of the MyListViewAdapter which now implements android.widget.AdapterView.OnItemClickListener
		//	note that you must set the OnItemClickListener AFTER setting the Adapter
		this.setOnItemClickListener(mMyListViewAdapter);
		

		//	FastScroll hardcoded to true
		this.setFastScrollEnabled(true);
	}

	/*
	 * http://developer.android.com/reference/android/widget/ArrayAdapter.html
	 * 
	 * There are many methods to manipulate the data in the ListView.
	 * addAll() looks useful is is only available with Android API 11 onwards.
	 * 
	 */

	public void addItem(MyDataClass pMyDataClass) {
		mMyListViewAdapter.add(pMyDataClass);
	}

	public void clearList() {
		mMyListViewAdapter.clear();
	}
}
