package uk.co.martinpearman.b4a.mylistview.arrayadapter;

import java.util.List;

import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ArrayAdapter;
import android.widget.TextView;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.BA.Hide;

@Hide
public class MyListViewAdapter extends ArrayAdapter<MyDataClass> implements OnItemClickListener{
	
	/*
	 * This is the custom ArrayAdapter class.
	 * 
	 * http://developer.android.com/reference/android/widget/ArrayAdapter.html
	 * 
	 * Version 1.1 implements the android.widget.AdapterView.OnItemClickListener.
	 * I had success implementing the View.OnItemClickListener but that required a lot of workaround code to identify the clicked View.
	 * android.widget.AdapterView.OnItemClickListener is the interface intended to be used to handle clicks on adapter items.
	 * 
	 * http://developer.android.com/reference/android/widget/AdapterView.OnItemClickListener.html
	 * 
	 */
	
	private BA mBA;
	private String mEventName;
	private int mItemLayoutResourceId;
	private LayoutInflater mLayoutInflater;
	private List<MyDataClass> mMyDataClassList;
	private String[] mTextViewIds;
	
	public MyListViewAdapter(BA pBA, int pItemLayoutResourceId, int pTextViewResourceId, List<MyDataClass> pMyDataClassList, String pEventName) {
		super(pBA.context, pItemLayoutResourceId, pTextViewResourceId, pMyDataClassList);
		
		mBA=pBA;	//	keep a reference to the Activity BA object
		mEventName=pEventName;
		mItemLayoutResourceId=pItemLayoutResourceId;
		
		/*
		 * A reference to the LayoutInflater is kept to avoid calling it each time a new ListItem is required.
		 * 
		 * But look at the Log output - when the ListView is created the LayoutInflater is used, after that it is seldom used as ListItems are recycled.
		 * If your ListItems vary in height then there is a chance the LayoutInflater will again be re-used.
		 * 
		 * You choose whether keeping a reference to it is a resource waste or not!
		 * 
		 */
		mLayoutInflater=LayoutInflater.from(pBA.context);
		
		mMyDataClassList=pMyDataClassList;
		
		/*
		 * These are the ids of the textViews in my ListItem layout.
		 * 
		 * MyListViewWrapper uses the same ids to add values to a MyDataClass instance.
		 * You'll probably want to use your own technique instead of my technique track TextView ids and Array values.
		 * 
		 */
		mTextViewIds=new String[]{"item_title", "item_description"};
	}
	
	/*
	 * A helper method to find a View in the ListItem.
	 */
	private static View findViewById(View pView, String pId) {
		return pView.findViewById(BA.applicationContext.getResources().getIdentifier(pId, "id", BA.packageName));
	}
	
	@Override
	public View getView(int pPosition, View pConvertView, ViewGroup pParent) {
		/*
		 * getView() is called when the ListView needs to make a ListItem visible.
		 * 
		 * A previously visible but no longer visible ListItem may be recycled otherwise a new ListItem is created.
		 * 
		 */
		if (pConvertView == null) {
			Log.i("B4A", "New ListItem created");
			pConvertView = mLayoutInflater.inflate(mItemLayoutResourceId, null);
		} else {
			Log.i("B4A", "Existing ListItem recycled");
		}
		MyDataClass dataItem = mMyDataClassList.get(pPosition);
		if (dataItem != null) {
			TextView textView;
			for(int i=0, j=mTextViewIds.length; i<j; i++){
				textView=(TextView)findViewById(pConvertView, mTextViewIds[i]);
				textView.setText((String) dataItem.get(mTextViewIds[i]));
			}
		}
		/*
		 * If dataItem is null and this is a recycled View then the recycled View will retain it's old values..
		 * 
		 * It's probably not possible/likely that dataItem will be null?
		 * 
		 */
		return pConvertView;
	}

	@Override
	public void onItemClick(AdapterView<?> pParent, View pView, int pPosition, long pId) {
		/*	this is the method that must be implemented as part of the AdapterView.OnItemClickListener
		 * 
		 * pParent is the MyListView instance
		 * pView is the inflated ListItem
		 * pPosition is the index of the clicked ListItem
		 * pId is i think only of use with a CursorAdapter as it will be the row id of the clicked ListItem in the Cursor.
		 */
		MyDataClass dataItem = mMyDataClassList.get(pPosition);
		Log.d("B4A", "The clicked ListItem item_title is '"+dataItem.get("item_title")+"'");
		mBA.raiseEvent(MyListViewAdapter.this, mEventName+"_itemclick", new Object[]{pPosition});
	}
}
